package
Version:
v0.3.0
Opens a new window with list of versions in this module.
Published: Jun 1, 2022
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Logger interface {
Debugf(format string, v ...interface{})
Errorf(format string, v ...interface{})
}
Logger defines interface that must be implemented by the user
who want to log the internal rimcu lib
NewDefaultLogger creates logger which doing nothing
Source Files
¶
Click to show internal directories.
Click to hide internal directories.